==> noahs-2.1.2.tar.gz: noahs/src/Plugin/Control/ControlSelect.php <==
<?php 
namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;

/**
 * @ControlPlugin(
 *   id = "select",
 *   label = @Translation("Select")
 * )
 */


class ControlSelect extends ControlBase {

	public function get_type() {
		return 'select';
	}

	public function content_template(array $params = []) {
		$data = $params['data'] ?? null;
    	$name = $params['name'] ?? null;
    	$value = $params['value'] ?? null;
		
		$attributes = '';
		$class = [];
		$class[] = 'form-control form-select';
		$selector = !empty($data['item']['update_selector_html']) ? 'data-update-selectorhtml="#widget-id-' .$data['wid'] . ' ' .$data['item']['update_selector_html'].'"' : null;
		if(!empty($data['item']['multiple']) && $data['item']['multiple'] === true){
			$name = $name . '[]';
			$attributes = 'multiple="true"';
		}


		
		if(!empty($data['item']['attributes'])){

			$attributes =  implode(' ', array_map(
				function ($key, $value) {
					if($key != 'class'){
						return sprintf('%s="%s"', $key, htmlspecialchars($value));
					}
				},
				array_keys($data['item']['attributes']),
				$data['item']['attributes']
			));
			$class[] = !empty($data['item']['attributes']['class']) ? $data['item']['attributes']['class'] : null;
		}
		$class = implode(" ", $class);
		$output = '<select name="'.$name.'" '.$attributes.'  class="'.$class.'" '.$selector.' field-settings>';



		if(!empty($data['item']['select_group_views'])){
	
			foreach ($data['item']['options'] as $groupName => $groupItems) {

				$output .= '<optgroup label="'.$groupItems[0]['master'].'">';
				foreach ($groupItems as $item) {
					$block_id_decoded = htmlspecialchars_decode($item['block_id'], ENT_QUOTES);
					$value_array = json_decode($value, true);
					$item_block_id_array = json_decode($block_id_decoded, true);
					$selected = ($value_array === $item_block_id_array) ? 'selected="selected"' : '';
					$output .= "<option value='{$item['block_id']}' {$selected}>{$item['text']}</option>";
				}
				$output .= '</optgroup>';
			}
		}else if(!empty($data['item']['select_group'])){
	
			foreach ($data['item']['options'] as $groupName => $groupItems) {

				$output .= '<optgroup label="'.$groupItems['text'].'">';
				foreach ($groupItems['options'] as $key => $item) {
					$selected = ( $value == $key) ? 'selected="selected"' : '';

					$output .= "<option value='{$key}' {$selected}>{$item}</option>";
				}
				$output .= '</optgroup>';
			}
		}else{
			foreach($data['item']['options'] as $key => $option){

				$selected = ( $value == $key) ? 'selected="selected"' : '';
				if(!empty($data['item']['multiple']) && $data['item']['multiple'] === true){
					$selected = (in_array($key, $value)) ? 'selected="selected"' : ''; // Verificar si $key está en $value (un array)
				}
				$output .= '<option value="'.$key.'" '.$selected.'>'. $option . '</option>';
			}
		}
 	
		$output .= '</select>';

		return $output;
	}

	public function get_default_settings() {
		return [
			'input_type' => 'select',
			'placeholder' => '',
			'title' => '',
		];
	}
}

==> noahs-2.1.3.tar.gz: noahs/src/Plugin/Control/ControlSelect.php <==
<?php 
namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;

/**
 * @ControlPlugin(
 *   id = "select",
 *   label = @Translation("Select")
 * )
 */


class ControlSelect extends ControlBase {

	public function get_type() {
		return 'select';
	}

	public function content_template(array $params = []) {
		$data = $params['data'] ?? null;
    	$name = $params['name'] ?? null;
    	$value = $params['value'] ?? null;
		
		$attributes = '';
		$class = [];
		$class[] = 'form-control form-select';
		$selector = !empty($data['item']['update_selector_html']) ? 'data-update-selectorhtml="#widget-id-' .$data['wid'] . ' ' .$data['item']['update_selector_html'].'"' : null;



 
		if(!empty($data['item']['attributes'])){

			$attributes =  implode(' ', array_map(
				function ($key, $value) {
					if($key != 'class'){
						return sprintf('%s="%s"', $key, htmlspecialchars($value));
					}
				},
				array_keys($data['item']['attributes']),
				$data['item']['attributes']
			));
			$class[] = !empty($data['item']['attributes']['class']) ? $data['item']['attributes']['class'] : null;
		}
		if(!empty($data['item']['multiple']) && $data['item']['multiple'] === true){
			$name = $name . '[]';
			$attributes .= ' multiple="true"';
		}
    $attributes .= 'data-select-value="' . htmlspecialchars(json_encode($value), ENT_QUOTES, 'UTF-8') . '"';
		$class = implode(" ", $class);
		$output = '<select name="'.$name.'" '.$attributes.'  class="'.$class.'" '.$selector.' field-settings>';

		if(!empty($data['item']['select_group_views'])){
	
			foreach ($data['item']['options'] as $groupName => $groupItems) {

				$output .= '<optgroup label="'.$groupItems[0]['master'].'">';
				foreach ($groupItems as $item) {
					$block_id_decoded = htmlspecialchars_decode($item['block_id'], ENT_QUOTES);
					$value_array = json_decode($value, true);
					$item_block_id_array = json_decode($block_id_decoded, true);
					$selected = ($value_array === $item_block_id_array) ? 'selected="selected"' : '';
					$output .= "<option value='{$item['block_id']}' {$selected}>{$item['text']}</option>";
				}
				$output .= '</optgroup>';
			}
		}else if(!empty($data['item']['select_group'])){
	
			foreach ($data['item']['options'] as $groupName => $groupItems) {

				$output .= '<optgroup label="'.$groupItems['text'].'">';
				foreach ($groupItems['options'] as $key => $item) {
					$selected = ( $value == $key) ? 'selected="selected"' : '';

					$output .= "<option value='{$key}' {$selected}>{$item}</option>";
				}
				$output .= '</optgroup>';
			}
		}else{

      foreach ($data['item']['options'] as $key => $option) {
        $selected = ($value == $key) ? 'selected="selected"' : '';
    
        if (!empty($data['item']['multiple']) && $data['item']['multiple'] === true) {
            if (is_array($value)) {
                $selected = (in_array($key, $value)) ? 'selected="selected"' : '';
            }
        }
    
        $output .= '<option value="' . $key . '" ' . $selected . '>' . $option . '</option>';
      }
		}
 	
		$output .= '</select>';

		return $output;
	}

	public function get_default_settings() {
		return [
			'input_type' => 'select',
			'placeholder' => '',
			'title' => '',
		];
	}
}
